(*---------------------------------------------------------------------------
   Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
   Distributed under the ISC license, see terms at the end of the file.
   webbrowser v0.6.0
  ---------------------------------------------------------------------------*)

let exec = Filename.basename Sys.executable_name
let log_err f = Format.eprintf ("%s: " ^^ f ^^ "@?") exec

let browse background prefix browser uris =
  let rec loop = function
  | [] -> 0
  | uri :: uris ->
      match Webbrowser.reload ~background ~prefix ?browser uri with
      | Error (`Msg e) -> log_err "%s" e; 1
      | Ok () -> loop uris
  in
  loop uris

(* Command line interface *)

open Cmdliner

let uris =
  let doc = "URI to open or reload." in
  Arg.(non_empty & pos_all string [] & info [] ~doc ~docv:"URI")

let doc = "Open and reload URIs in web browsers"
let man =
  [ `S "DESCRIPTION";
    `P "The $(b,$(tname)) command opens or reloads URIs specified
        on the command line.";
    `S "BUGS";
    `P "This program is distributed with the OCaml webbrowser library.
        See $(i,http://erratique.ch/software/webbrowser) for contact information."; ]

let cmd =
  let info = Term.info "browse" ~doc ~man in
  let t = Term.(const browse $ Webbrowser_cli.background $
                Webbrowser_cli.prefix $ Webbrowser_cli.browser $ uris)
  in
  (t, info)

let () = match Term.eval cmd with
| `Error _ -> exit 1
| `Ok v -> exit v
| _ -> exit 0

(*---------------------------------------------------------------------------
   Copyright (c) 2016 Daniel C. Bünzli

   Permission to use, copy, modify, and/or distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
   copyright notice and this permission notice appear in all copies.

   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ---------------------------------------------------------------------------*)
